@@ -7,4 +7,6 @@ class LoginFinalizeHandler(LoginStepHandler):
     def next_step(self, accumulated, last_response: Response) -> ({}, Response):
         del accumulated["login_barcode"]
         del accumulated["login_success_url"]
-        return accumulated, OnlineChecker.check_online(accumulated, self.session)
+        resp = OnlineChecker.check_online(accumulated, self.session)
+        print(resp)
+        return accumulated, resp
